==> pegasus-2.3.2.tar.bz2: pegasus-2.3.2/src/Pegasus/Common/ContentLanguageElement.cpp <==
//%2003////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002  BMC Software, Hewlett-Packard Development
// Company, L. P., IBM Corp., The Open Group, Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L. P.;
// IBM Corp.; EMC Corporation, The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//==============================================================================
//
// Author: Humberto Rivero (hurivero@us.ibm.com)
//
// Modified By:
// 
//%/////////////////////////////////////////////////////////////////////////////

#include <Pegasus/Common/ContentLanguageElement.h>

//PEGASUS_USING_STD;
PEGASUS_NAMESPACE_BEGIN

#define PEGASUS_ARRAY_T ContentLanguageElement
#include "ArrayImpl.h"
#undef PEGASUS_ARRAY_T

    const ContentLanguageElement ContentLanguageElement::EMPTY = ContentLanguageElement();

	ContentLanguageElement ContentLanguageElement::EMPTY_REF = ContentLanguageElement();

	ContentLanguageElement::ContentLanguageElement(String language_tag): LanguageElement(language_tag){}
	
	ContentLanguageElement::ContentLanguageElement(String language, String country, String variant):
										LanguageElement(language,country,variant){} 

	ContentLanguageElement::ContentLanguageElement(const ContentLanguageElement &rhs): LanguageElement(rhs){}
	
	ContentLanguageElement::~ContentLanguageElement(){}

PEGASUS_NAMESPACE_END

==> pegasus-2.5.tar.bz2: pegasus-2.5/src/Pegasus/Common/ContentLanguageElement.cpp <==
//%2005////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation, The Open Group.
// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; VERITAS Software Corporation; The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//==============================================================================
//
// Author: Humberto Rivero (hurivero@us.ibm.com)
//
// Modified By:
// 
//%/////////////////////////////////////////////////////////////////////////////

#include <Pegasus/Common/ContentLanguageElement.h>
#include <Pegasus/Common/LanguageElementRep.h>

PEGASUS_NAMESPACE_BEGIN

#define PEGASUS_ARRAY_T ContentLanguageElement
#include "ArrayImpl.h"
#undef PEGASUS_ARRAY_T

    const ContentLanguageElement ContentLanguageElement::EMPTY = ContentLanguageElement();

	ContentLanguageElement ContentLanguageElement::EMPTY_REF = ContentLanguageElement();

	ContentLanguageElement::ContentLanguageElement():LanguageElement(){
	}

	ContentLanguageElement::ContentLanguageElement(String language_tag): LanguageElement(language_tag){
	}
	
	ContentLanguageElement::ContentLanguageElement(String language, String country, String variant):
										LanguageElement(language,country,variant){
	} 

	ContentLanguageElement::ContentLanguageElement(const LanguageElement &le):LanguageElement(le){}

	ContentLanguageElement::ContentLanguageElement(const ContentLanguageElement &rhs):LanguageElement(rhs){
	}
	
	ContentLanguageElement::~ContentLanguageElement(){
	}

PEGASUS_NAMESPACE_END
